<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Vehicle;
use App\Models\VehicleImage;
use App\Models\Brand;

class VehicleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        //return $request;
        try{
            $brands=Brand::select('id','name')->get();
            if($request->q !='' || $request->price !='' ){
                $vehicles=Vehicle::orwhere('preisvorstellung','like', '%'.$request->price.'%')->orwhere('marke_id','like', '%'.$request->q.'%')->with('vehicledetail','vehicleimage')->orderBy('created_at','DESC')->paginate(10);
            }
            else{
            
            $vehicles=Vehicle::with('vehicledetail','vehicleimage')->orderBy('created_at','DESC')->paginate(10);
            }
            return view('vehicle.index',compact('vehicles','brands'));
        }catch (Exception $e){
            \Session::flash('danger', $e->getMessage());
            return redirect()->back();
        }
    }

    public function getvehicleList(Request $request)
    {
        //return $request;
        $data = Vehicle::with('vehicledetail','vehicleimage')->get();
        

        return Datatables::of($data)
            ->addColumn('action', function ($data)  {
                $output = '';
                
                    $output = '<div class="table-actions">
                                <a href="javascript:;"  class="edituserid"  data-id="'. $data->id .'" data-url="'. url('user/' . $data->id) . '"><i class="ik ik-edit-2 f-16 mr-15 text-green"></i></a>
                                
                                <a href="' . url('user/delete/' . $data->id) . '"  ><i class="ik ik-trash-2 f-16 text-red"></i></a>
                            </div>';
                

                return $output;
            })
            ->rawColumns(['action'])
            ->make(true);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        try{
            $brands=Brand::select('id','name')->get();
            return view('vehicle.create',compact('brands'));
        }catch (Exception $e){
            \Session::flash('danger', $e->getMessage());
            return redirect()->back();
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
        //return $request;
            $vehicle= Vehicle::create($request->except('_token','itemimages'));

            if(isset($request['itemimages']))
            {
                //return $request['itemimages'];
                foreach($request['itemimages'] as $galleryimages){
                    //return $galleryimage;
                    $file_name=  $this->files($galleryimages);
                    $data['vehicle_id'] =$vehicle->id;
                    $data['bilder'] = $file_name;
                     //return $data;
                    VehicleImage::create($data);
                }
            }

            return redirect()->route('vehicle.index');
        }catch (Exception $e){
            \Session::flash('danger', $e->getMessage());
            return redirect()->back();
        }
    }

    public  function files($file){
        //return $file;
        $image = $file;
        $fileInfo = $image->getClientOriginalName();
        $uniqueId= time().mt_rand();

        $filename = $uniqueId;
        $extension = pathinfo($fileInfo, PATHINFO_EXTENSION);
        $file_name= $filename.'.'.$extension;
        $image->move('images\upload\itemthumbnail/',$file_name);
        //$request['image']= $file_name;
        return $data['image'] = $file_name;
                
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        try{
            //return $id;
            $vehicle=Vehicle::where('id',$id)->with('vehicledetail','vehicleimage')->first();
            return view('vehicle.show',compact('vehicle'));
        }catch (Exception $e){
            \Session::flash('danger', $e->getMessage());
            return redirect()->back();
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        try{
        $brands=Brand::select('id','name')->get();
        $vehicle=Vehicle::where('id',$id)->with('vehicledetail','vehicleimage')->first();
        return view('vehicle.edit',compact('vehicle','brands'));
        }catch (Exception $e){
            \Session::flash('danger', $e->getMessage());
            return redirect()->back();
        }
    }

    public function vehicleprice($id){
        return view('vehicle.vehicleprice',compact('id'));
    }

    public function updateprice(Request $request, $id){
        //return $request;
        $vehicle = Vehicle::where('id',$id)->update($request->except('_token','_method'));
        return redirect()->route('vehicle.index');
    }

    public  function vehiclepdf($id)
    {
        //return $id;
        $vehicle = Vehicle::find($id);
        return view('vehicle.blue',compact('vehicle'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        try{
        //return $request;
        $vehicle= Vehicle::where('id',$id)->update($request->except('_token','itemimages','_method'));

        if(isset($request['itemimages']))
        {
            //return $request['itemimages'];
            foreach($request['itemimages'] as $galleryimages){
                //return $galleryimage;
                $file_name=  $this->files($galleryimages);
                $data['vehicle_id'] =$id;
                $data['bilder'] = $file_name;
                 //return $data;
                VehicleImage::create($data);
            }
        }

        return redirect()->route('vehicle.index');
        }catch (Exception $e){
            \Session::flash('danger', $e->getMessage());
            return redirect()->back();
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
